pub enum ProgramPoint {
Invalid,
Block {
block: BlockRef,
position: Position,
},
Op {
op: OperationRef,
position: Position,
},
}Expand description
ProgramPoint represents a specific location in the execution of a program.
A program point consists of two parts:
- An anchor, either a block or operation
- A position, i.e. the direction relative to the anchor to which the program point refers
A program point can be reified as a cursor within a block, such that an operation inserted at the cursor will be placed at the specified position relative to the anchor.
Variants
Invalid
A program point which refers to nothing, and is always invalid if used
Block
A program point referring to the entry or exit of a block
Fields
Op
A program point referring to the entry or exit of an operation
Fields
op: OperationRefThe operation this program point refers to
Implementations
Sourceimpl ProgramPoint
impl ProgramPoint
Sourcepub fn before(entity: impl Into<ProgramPoint>) -> Self
pub fn before(entity: impl Into<ProgramPoint>) -> Self
Create a ProgramPoint at entry to entity, i.e. “before”
Sourcepub fn after(entity: impl Into<ProgramPoint>) -> Self
pub fn after(entity: impl Into<ProgramPoint>) -> Self
Create a ProgramPoint at exit from entity, i.e. “after”
Sourcepub fn at_start_of(block: impl Into<BlockPoint>) -> Self
pub fn at_start_of(block: impl Into<BlockPoint>) -> Self
Create a ProgramPoint at entry to block, i.e. “before”
Sourcepub fn at_end_of(block: impl Into<BlockPoint>) -> Self
pub fn at_end_of(block: impl Into<BlockPoint>) -> Self
Create a ProgramPoint at exit from block, i.e. “after”
Sourcepub fn is_at_block_start(&self) -> bool
pub fn is_at_block_start(&self) -> bool
Returns true if this program point is at the start of the containing block
Sourcepub fn is_at_block_end(&self) -> bool
pub fn is_at_block_end(&self) -> bool
Returns true if this program point is at the end of the containing block
Sourcepub fn block(&self) -> Option<BlockRef>
pub fn block(&self) -> Option<BlockRef>
Returns the block of the program point anchor.
Returns None, if the program point is either invalid, or pointing to an orphaned operation
Sourcepub fn operation(&self) -> Option<OperationRef>
pub fn operation(&self) -> Option<OperationRef>
Returns the program point anchor as an operation.
Returns None if the program point is either invalid, or not pointing to a specific op
Sourcepub fn next_operation(&self) -> Option<OperationRef>
pub fn next_operation(&self) -> Option<OperationRef>
Returns the operation after Self::operation, relative to this program point.
If the current program point is in an orphaned operation, this will return the current op.
Returns None if the program point is either invalid, or not pointing to a specific op
Sourcepub fn prev_operation(&self) -> Option<OperationRef>
pub fn prev_operation(&self) -> Option<OperationRef>
Returns the operation preceding Self::operation, relative to this program point.
If the current program point is in an orphaned operation, this will return the current op.
Returns None if the program point is either invalid, or not pointing to a specific op
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Returns true if this program point refers to a valid program point
Sourcepub fn cursor<'a, 'b: 'a, 'c: 'b>(
&'c self,
) -> Option<EntityProjection<'b, EntityListCursor<'a, Operation>>>
pub fn cursor<'a, 'b: 'a, 'c: 'b>( &'c self, ) -> Option<EntityProjection<'b, EntityListCursor<'a, Operation>>>
Obtain an immutable cursor in the block corresponding to this program point.
The resulting cursor can have as_pointer or get called on it to get the operation to
which this point is relative. The intuition around where the cursor is placed for a given
program point can be understood as answering the question of “where does the cursor need
to be, such that if I inserted an op at that cursor, that the insertion would be placed at
the referenced program point (semantically before or after an operation or block). The
specific rules are as follows:
- If “before” a block, the resulting cursor is the null cursor for the containing block, since an insertion at the null cursor will be placed at the start of the block.
- If “after” a block, the cursor is placed on the last operation in the block, as insertion will place the inserted op at the end of the block
- If “before” an operation, the cursor is placed on the operation immediately preceding
self, or a null cursor is returned. In both cases, an insertion at the returned cursor would be placed immediately beforeself - If “after” an operation, the cursor is placed on the operation in
self, so that insertion will place the inserted op immediately afterself.
NOTE: The block to which this program point refers will be borrowed for the lifetime of the returned EntityProjection.
Sourcepub fn cursor_mut<'a, 'b: 'a, 'c: 'b>(
&'c mut self,
) -> Option<EntityProjectionMut<'b, EntityListCursorMut<'a, Operation>>>
pub fn cursor_mut<'a, 'b: 'a, 'c: 'b>( &'c mut self, ) -> Option<EntityProjectionMut<'b, EntityListCursorMut<'a, Operation>>>
Same as Self::cursor, but obtains a mutable cursor instead.
NOTE: The block to which this program point refers will be borrowed mutably for the lifetime of the returned EntityProjectionMut.