EntityList

Struct EntityList 

pub struct EntityList<T> { /* private fields */ }

Implementations

Source

impl<T> EntityList<T>

pub fn new() -> Self

Construct a new, empty EntityList

pub fn is_empty(&self) -> bool

Returns true if this list is empty

pub fn len(&self) -> usize

Returns the number of entities in this list

pub fn front(&self) -> EntityListCursor<'_, T>

Get an EntityListCursor pointing to the first entity in the list, or the null object if the list is empty

pub fn back(&self) -> EntityListCursor<'_, T>

Get an EntityListCursor pointing to the last entity in the list, or the null object if the list is empty

pub fn iter(&self) -> EntityListIter<'_, T>

Get an iterator over the entities in this list

The iterator returned produces EntityRefs for each item in the list, with their lifetime bound to the list itself, not the iterator.

pub unsafe fn cursor_from_ptr( &self, ptr: UnsafeIntrusiveEntityRef<T>, ) -> EntityListCursor<'_, T>

Get a cursor to the item pointed to by ptr.

Safety

This function may only be called when it is known that ptr refers to an entity which is linked into this list. This operation will panic if the entity is not linked into any list, and may result in undefined behavior if the operation is linked into a different list.

Source

impl<T: EntityListItem> EntityList<T>

pub unsafe fn cursor_mut_from_ptr( &mut self, ptr: UnsafeIntrusiveEntityRef<T>, ) -> EntityListCursorMut<'_, T>

Get a mutable cursor to the item pointed to by ptr.

Safety

This function may only be called when it is known that ptr refers to an entity which is linked into this list. This operation will panic if the entity is not linked into any list, and may result in undefined behavior if the operation is linked into a different list.

pub fn front_mut(&mut self) -> EntityListCursorMut<'_, T>

Get an EntityListCursorMut pointing to the first entity in the list, or the null object if the list is empty

pub fn back_mut(&mut self) -> EntityListCursorMut<'_, T>

Get an EntityListCursorMut pointing to the last entity in the list, or the null object if the list is empty

pub fn push_front(&mut self, entity: UnsafeIntrusiveEntityRef<T>)

Prepend entity to this list

pub fn push_back(&mut self, entity: UnsafeIntrusiveEntityRef<T>)

Append entity to this list

pub fn pop_front(&mut self) -> Option<UnsafeIntrusiveEntityRef<T>>

Remove the entity at the front of the list, returning its UnsafeIntrusiveEntityRef

Returns None if the list is empty.

pub fn pop_back(&mut self) -> Option<UnsafeIntrusiveEntityRef<T>>

Remove the entity at the back of the list, returning its UnsafeIntrusiveEntityRef

Returns None if the list is empty.

pub fn clear(&mut self)

Removes all items from this list.

This will unlink all entities currently in the list, which requires iterating through all elements in the list. If the entities may be used again, this ensures that their intrusive link is properly unlinked.

pub fn fast_clear(&mut self)

Empties the list without properly unlinking the intrusive links of the items in the list.

Since this does not unlink any objects, any attempts to link these objects into another EntityList will fail but will not cause any memory unsafety. To unlink those objects manually, you must call the force_unlink function on the link.

pub fn take(&mut self) -> Self

Takes all the elements out of the EntityList, leaving it empty.

The taken elements are returned as a new EntityList.