EntityMut

Struct EntityMut 

pub struct EntityMut<'b, T: ?Sized> { /* private fields */ }
A guard that provides exclusive access to an IR entity

Implementations

Source

impl<'b, T: ?Sized> EntityMut<'b, T>

pub fn map<U: ?Sized, F>(orig: Self, f: F) -> EntityMut<'b, U>
where F: FnOnce(&mut T) -> &mut U,

Map this mutable reference to a derived mutable reference.

pub fn project<'to, 'from: 'to, To, F>( orig: EntityMut<'from, T>, f: F, ) -> EntityProjectionMut<'from, To>
where F: FnOnce(&'to mut T) -> To, To: 'to,

Project this mutable borrow into a owned (but semantically borrowed) value that inherits ownership of the underlying mutable borrow.

pub fn map_split<U: ?Sized, V: ?Sized, F>( orig: Self, f: F, ) -> (EntityMut<'b, U>, EntityMut<'b, V>)
where F: FnOnce(&mut T) -> (&mut U, &mut V),

Splits an EntityMut into multiple EntityMuts for different components of the borrowed data.

The underlying entity will remain mutably borrowed until both returned EntityMuts go out of scope.

The entity is already mutably borrowed, so this cannot fail.

This is an associated function that needs to be used as EntityMut::map_split(...), so as to avoid conflicting with any method of the same name accessible via the Deref impl.

Examples
use midenc_hir::*;
use blink_alloc::Blink;

let alloc = Blink::default();
let mut entity = UnsafeEntityRef::new([1, 2, 3, 4], &alloc);
let borrow = entity.borrow_mut();
let (mut begin, mut end) = EntityMut::map_split(borrow, |slice| slice.split_at_mut(2));
assert_eq!(*begin, [1, 2]);
assert_eq!(*end, [3, 4]);
begin.copy_from_slice(&[4, 3]);
end.copy_from_slice(&[2, 1]);
pub fn into_entity_ref(self) -> EntityRef<'b, T>

Convert this mutable borrow into an immutable borrow