pub struct EntityProjectionMut<'b, T: 'b> { /* private fields */ }Expand description
Represents a projection of an EntityMut into an owned value.
This retains the lifetime of the borrow, while allowing the projection itself to be owned. This is useful in cases where you would like to return a value derived from an EntityMut from a function, when the borrowed entity outlives the function itself. Since EntityMut can only represent references, deriving owned (but semantically borrowed) values from an EntityMut cannot be returned from an enclosing function, unlike if the value was a reference.
NOTE: An EntityProjectionMut takes ownership of the EntityMut from which it was derived, and propagates the lifetime of the borrowed entity. When this type is dropped, so is the original borrow.
Implementations
Sourceimpl<'b, T> EntityProjectionMut<'b, T>
impl<'b, T> EntityProjectionMut<'b, T>
pub fn map<U, F>(orig: Self, f: F) -> EntityProjectionMut<'b, U>where
F: FnOnce(T) -> U,