EntityRef

Struct EntityRef 

pub struct EntityRef<'b, T: ?Sized + 'b> { /* private fields */ }
A guard that ensures a reference to an IR entity cannot be mutably aliased

Implementations

Source

impl<'b, T: ?Sized> EntityRef<'b, T>

pub fn map<U: ?Sized, F>(orig: Self, f: F) -> EntityRef<'b, U>
where F: FnOnce(&T) -> &U,

Map this reference to a derived reference.

pub fn project<'to, 'from: 'to, To, F>( orig: EntityRef<'from, T>, f: F, ) -> EntityProjection<'from, To>
where F: FnOnce(&'to T) -> To, To: 'to,

Project this borrow into a owned (but semantically borrowed) value that inherits ownership of the underlying borrow.

pub fn into_entity_mut(self) -> Result<EntityMut<'b, T>, Self>

Try to convert this immutable borrow into a mutable borrow, if it is the only immutable borrow

pub fn into_borrow_ref(self) -> BorrowRef<'b>

pub fn from_raw_parts(value: NonNull<T>, borrow: BorrowRef<'b>) -> Self

Source

impl<T: Attribute> EntityRef<'_, T>

pub fn as_attribute_ref(&self) -> AttributeRef

Reconstitutes the type-erased intrusive handle for this borrowed attribute.

Source

impl EntityRef<'_, dyn Attribute>

pub fn as_attribute_ref(&self) -> AttributeRef

Reconstitutes the type-erased intrusive handle for this borrowed attribute.