pub struct EntityList<T> { /* private fields */ }Implementations
Sourceimpl<T> EntityList<T>
impl<T> EntityList<T>
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new, empty EntityList
Sourcepub fn front(&self) -> EntityListCursor<'_, T>
pub fn front(&self) -> EntityListCursor<'_, T>
Get an EntityListCursor pointing to the first entity in the list, or the null object if the list is empty
Sourcepub fn back(&self) -> EntityListCursor<'_, T>
pub fn back(&self) -> EntityListCursor<'_, T>
Get an EntityListCursor pointing to the last entity in the list, or the null object if the list is empty
Sourcepub fn iter(&self) -> EntityListIter<'_, T> ⓘ
pub fn iter(&self) -> EntityListIter<'_, T> ⓘ
Get an iterator over the entities in this list
The iterator returned produces EntityRefs for each item in the list, with their lifetime bound to the list itself, not the iterator.
Sourcepub unsafe fn cursor_from_ptr(
&self,
ptr: UnsafeIntrusiveEntityRef<T>,
) -> EntityListCursor<'_, T>
pub unsafe fn cursor_from_ptr( &self, ptr: UnsafeIntrusiveEntityRef<T>, ) -> EntityListCursor<'_, T>
Get a cursor to the item pointed to by ptr.
Safety
This function may only be called when it is known that ptr refers to an entity which is
linked into this list. This operation will panic if the entity is not linked into any list,
and may result in undefined behavior if the operation is linked into a different list.
Sourceimpl<T: EntityListItem> EntityList<T>
impl<T: EntityListItem> EntityList<T>
Sourcepub unsafe fn cursor_mut_from_ptr(
&mut self,
ptr: UnsafeIntrusiveEntityRef<T>,
) -> EntityListCursorMut<'_, T>
pub unsafe fn cursor_mut_from_ptr( &mut self, ptr: UnsafeIntrusiveEntityRef<T>, ) -> EntityListCursorMut<'_, T>
Get a mutable cursor to the item pointed to by ptr.
Safety
This function may only be called when it is known that ptr refers to an entity which is
linked into this list. This operation will panic if the entity is not linked into any list,
and may result in undefined behavior if the operation is linked into a different list.
Sourcepub fn front_mut(&mut self) -> EntityListCursorMut<'_, T>
pub fn front_mut(&mut self) -> EntityListCursorMut<'_, T>
Get an EntityListCursorMut pointing to the first entity in the list, or the null object if the list is empty
Sourcepub fn back_mut(&mut self) -> EntityListCursorMut<'_, T>
pub fn back_mut(&mut self) -> EntityListCursorMut<'_, T>
Get an EntityListCursorMut pointing to the last entity in the list, or the null object if the list is empty
Sourcepub fn push_front(&mut self, entity: UnsafeIntrusiveEntityRef<T>)
pub fn push_front(&mut self, entity: UnsafeIntrusiveEntityRef<T>)
Prepend entity to this list
Sourcepub fn push_back(&mut self, entity: UnsafeIntrusiveEntityRef<T>)
pub fn push_back(&mut self, entity: UnsafeIntrusiveEntityRef<T>)
Append entity to this list
Sourcepub fn pop_front(&mut self) -> Option<UnsafeIntrusiveEntityRef<T>>
pub fn pop_front(&mut self) -> Option<UnsafeIntrusiveEntityRef<T>>
Remove the entity at the front of the list, returning its UnsafeIntrusiveEntityRef
Returns None if the list is empty.
Sourcepub fn pop_back(&mut self) -> Option<UnsafeIntrusiveEntityRef<T>>
pub fn pop_back(&mut self) -> Option<UnsafeIntrusiveEntityRef<T>>
Remove the entity at the back of the list, returning its UnsafeIntrusiveEntityRef
Returns None if the list is empty.
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Removes all items from this list.
This will unlink all entities currently in the list, which requires iterating through all elements in the list. If the entities may be used again, this ensures that their intrusive link is properly unlinked.
Sourcepub fn fast_clear(&mut self)
pub fn fast_clear(&mut self)
Empties the list without properly unlinking the intrusive links of the items in the list.
Since this does not unlink any objects, any attempts to link these objects into another
EntityList will fail but will not cause any memory unsafety. To unlink those objects
manually, you must call the force_unlink function on the link.
Sourcepub fn take(&mut self) -> Self
pub fn take(&mut self) -> Self
Takes all the elements out of the EntityList, leaving it empty.
The taken elements are returned as a new EntityList.